==> aws-java-sdk-codebuild-1.11.68-sources.jar: com/amazonaws/services/codebuild/model/transform/ListBuildsForProjectRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.codebuild.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.codebuild.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ListBuildsForProjectRequest Marshaller
 */
public class ListBuildsForProjectRequestMarshaller implements Marshaller<Request<ListBuildsForProjectRequest>, ListBuildsForProjectRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public ListBuildsForProjectRequestMarshaller(SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<ListBuildsForProjectRequest> marshall(ListBuildsForProjectRequest listBuildsForProjectRequest) {

        if (listBuildsForProjectRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<ListBuildsForProjectRequest> request = new DefaultRequest<ListBuildsForProjectRequest>(listBuildsForProjectRequest, "AWSCodeBuild");
        request.addHeader("X-Amz-Target", "CodeBuild_20161006.ListBuildsForProject");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (listBuildsForProjectRequest.getProjectName() != null) {
                jsonGenerator.writeFieldName("projectName").writeValue(listBuildsForProjectRequest.getProjectName());
            }
            if (listBuildsForProjectRequest.getSortOrder() != null) {
                jsonGenerator.writeFieldName("sortOrder").writeValue(listBuildsForProjectRequest.getSortOrder());
            }
            if (listBuildsForProjectRequest.getNextToken() != null) {
                jsonGenerator.writeFieldName("nextToken").writeValue(listBuildsForProjectRequest.getNextToken());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-codebuild-1.11.75-sources.jar: com/amazonaws/services/codebuild/model/transform/ListBuildsForProjectRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.codebuild.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.codebuild.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ListBuildsForProjectRequest Marshaller
 */
public class ListBuildsForProjectRequestMarshaller implements Marshaller<Request<ListBuildsForProjectRequest>, ListBuildsForProjectRequest> {

    private final SdkJsonMarshallerFactory protocolFactory;

    public ListBuildsForProjectRequestMarshaller(SdkJsonMarshallerFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<ListBuildsForProjectRequest> marshall(ListBuildsForProjectRequest listBuildsForProjectRequest) {

        if (listBuildsForProjectRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<ListBuildsForProjectRequest> request = new DefaultRequest<ListBuildsForProjectRequest>(listBuildsForProjectRequest, "AWSCodeBuild");
        request.addHeader("X-Amz-Target", "CodeBuild_20161006.ListBuildsForProject");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (listBuildsForProjectRequest.getProjectName() != null) {
                jsonGenerator.writeFieldName("projectName").writeValue(listBuildsForProjectRequest.getProjectName());
            }
            if (listBuildsForProjectRequest.getSortOrder() != null) {
                jsonGenerator.writeFieldName("sortOrder").writeValue(listBuildsForProjectRequest.getSortOrder());
            }
            if (listBuildsForProjectRequest.getNextToken() != null) {
                jsonGenerator.writeFieldName("nextToken").writeValue(listBuildsForProjectRequest.getNextToken());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
